@@ -38,7 +38,7 @@ class knumber_float;
 class knumber_base {
 public:
 	virtual ~knumber_base() { }
-	
+
 public:
 	virtual knumber_base *clone() = 0;
 
@@ -46,7 +46,7 @@ public:
 	virtual QString toString(int precision) const = 0;
 	virtual quint64 toUint64() const = 0;
 	virtual qint64 toInt64() const = 0;
-	
+
 public:
 	virtual bool is_integer() const = 0;
 	virtual bool is_zero() const = 0;
@@ -59,14 +59,14 @@ public:
 	virtual knumber_base *mul(knumber_base *rhs) = 0;
 	virtual knumber_base *div(knumber_base *rhs) = 0;
 	virtual knumber_base *mod(knumber_base *rhs) = 0;
-	
+
 public:
 	// logical operators
 	virtual knumber_base *bitwise_and(knumber_base *rhs) = 0;
 	virtual knumber_base *bitwise_xor(knumber_base *rhs) = 0;
 	virtual knumber_base *bitwise_or(knumber_base *rhs) = 0;
 	virtual knumber_base *bitwise_shift(knumber_base *rhs) = 0;
-	
+
 public:
 	// algebraic functions
 	virtual knumber_base *pow(knumber_base *rhs) = 0;
@@ -77,7 +77,7 @@ public:
 	virtual knumber_base *cbrt() = 0;
 	virtual knumber_base *factorial() = 0;
 	virtual knumber_base *reciprocal() = 0;
-	
+
 public:
 	// special functions
 	virtual knumber_base *log2() = 0;
@@ -85,9 +85,11 @@ public:
 	virtual knumber_base *ln() = 0;
 	virtual knumber_base *exp2() = 0;
 	virtual knumber_base *exp10() = 0;
+	virtual knumber_base *floor() = 0;
+	virtual knumber_base *ceil() = 0;
 	virtual knumber_base *exp() = 0;
 	virtual knumber_base *bin(knumber_base *rhs) = 0;
-	
+
 public:
 	// trig functions
 	virtual knumber_base *sin() = 0;
@@ -102,7 +104,8 @@ public:
 	virtual knumber_base *asinh() = 0;
 	virtual knumber_base *acosh() = 0;
 	virtual knumber_base *atanh() = 0;
-	
+	virtual knumber_base *tgamma() = 0;
+
 public:
 	// comparison
 	virtual int compare(knumber_base *rhs) = 0;
