@@ -50,7 +50,7 @@ public:
 
 public:
 	virtual knumber_base *clone();
-	
+
 public:
 	virtual QString toString(int precision) const;
 	virtual quint64 toUint64() const;
@@ -60,20 +60,20 @@ public:
 	virtual bool is_integer() const;
 	virtual bool is_zero() const;
 	virtual int sign() const;
-	
+
 public:
     virtual knumber_base *add(knumber_base *rhs);
     virtual knumber_base *sub(knumber_base *rhs);
     virtual knumber_base *mul(knumber_base *rhs);
     virtual knumber_base *div(knumber_base *rhs);
 	virtual knumber_base *mod(knumber_base *rhs);
-	
+
 public:
 	virtual knumber_base *bitwise_and(knumber_base *rhs);
 	virtual knumber_base *bitwise_xor(knumber_base *rhs);
 	virtual knumber_base *bitwise_or(knumber_base *rhs);
 	virtual knumber_base *bitwise_shift(knumber_base *rhs);
-	
+
 public:
 	virtual knumber_base *pow(knumber_base *rhs);
 	virtual knumber_base *neg();
@@ -83,16 +83,19 @@ public:
 	virtual knumber_base *cbrt();
 	virtual knumber_base *factorial();
 	virtual knumber_base *reciprocal();
-	
+	virtual knumber_base *tgamma();
+
 public:
 	virtual knumber_base *log2();
 	virtual knumber_base *log10();
 	virtual knumber_base *ln();
 	virtual knumber_base *exp2();
+	virtual knumber_base *floor();
+	virtual knumber_base *ceil();
 	virtual knumber_base *exp10();
 	virtual knumber_base *exp();
 	virtual knumber_base *bin(knumber_base *rhs);
-		
+
 public:
 	virtual knumber_base *sin();
 	virtual knumber_base *cos();
@@ -106,10 +109,10 @@ public:
 	virtual knumber_base *asinh();
 	virtual knumber_base *acosh();
 	virtual knumber_base *atanh();
-	
+
 public:
 	virtual int compare(knumber_base *rhs);
-	
+
 private:
 	knumber_integer *numerator() const;
 	knumber_integer *denominator() const;
